==> haskell-citeproc-0.8.1.1-52-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1.1
visibility:           public
id:                   citeproc-0.8.1.1-6eCvgHGViM08ZigXcHI7BS
key:                  citeproc-0.8.1.1-6eCvgHGViM08ZigXcHI7BS
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  9aaf37bb782d0f52109143c96a447496
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1.1-6eCvgHGViM08ZigXcHI7BS
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    containers-0.6.7 data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    pandoc-types-1.23.1-1bQhO4167wJAXeIDmZ5obj
    safe-0.3.21-FBimV6u2RMNDKpiH5qP0vN
    scientific-0.3.8.0-L88GQ4rEhQfGc3NVSCAVTu text-2.0.2
    text-icu-0.8.0.5-KBWk9ZdXuGZ3Cal1MTfm4P transformers-0.5.6.2
    unicode-collation-0.1.3.6-EfPsDulzymKHVFxu0v3g5x
    uniplate-1.6.13-JXA4VCV4vwKlFPDh1oFOb
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-citeproc-0.8.1.1-71-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1.1
visibility:           public
id:                   citeproc-0.8.1.1-ja27luBGtkAq4frTY1ZQc
key:                  citeproc-0.8.1.1-ja27luBGtkAq4frTY1ZQc
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  03f9bfde984abfdb22e8f3a95c98d57b
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1.1-ja27luBGtkAq4frTY1ZQc
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    containers-0.6.7 data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    pandoc-types-1.23.1-2Af65ACjfKtCfKJLbmCXaX
    safe-0.3.21-JMKA2bKqr97GM6r3OADsOi
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C text-2.0.2
    text-icu-0.8.0.5-8fDNWwB3N9bDuWcJ0CIStk transformers-0.5.6.2
    unicode-collation-0.1.3.6-CJrNwu6X1m0LT3nZ5F4EKq
    uniplate-1.6.13-6AZxRZigT9K4tvBk80lMWK
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
